"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DockerStore = void 0;
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
const ts_log_1 = require("ts-log");
const conf_1 = __importDefault(require("conf"));
class DockerStore {
    constructor(logger) {
        this.conf = new conf_1.default(Object.assign(Object.assign({}, process.env.NODE_ENV === 'test' ? { projectName: 'cardano-graphql-test' } : {}), { configName: 'docker', schema: {
                compose: {
                    type: 'object',
                    properties: {
                        createdAt: {
                            type: 'number'
                        }
                    }
                },
                managedImages: {
                    type: 'array',
                    items: {
                        type: 'string'
                    }
                },
                secrets: {
                    type: 'object',
                    properties: {
                        createdAt: {
                            type: 'number'
                        }
                    }
                },
                workingDirectory: {
                    type: 'string'
                }
            } }));
        this.logger = logger || ts_log_1.dummyLogger;
    }
    createSecrets(password, user) {
        return __awaiter(this, void 0, void 0, function* () {
            yield fs_extra_1.default.ensureDir(this.secretsDir);
            yield Promise.all([
                fs_extra_1.default.writeFile(path_1.default.join(this.secretsDir, 'postgres_db'), 'cexplorer'),
                fs_extra_1.default.writeFile(path_1.default.join(this.secretsDir, 'postgres_password'), password),
                fs_extra_1.default.writeFile(path_1.default.join(this.secretsDir, 'postgres_user'), user)
            ]);
            yield this.set('secrets', { createdAt: Date.now() });
            this.logger.info('Secrets created');
        });
    }
    cleanup() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                if ((yield fs_extra_1.default.stat(this.secretsDir)).isDirectory()) {
                    yield fs_extra_1.default.remove(this.localConfigDir);
                    this.logger.info('Secrets removed');
                }
                else {
                    this.logger.debug('No secrets to remove');
                }
                if (this.get('compose') !== undefined) {
                    if ((yield fs_extra_1.default.stat(this.dockerComposeFilePath)).isFile()) {
                        yield fs_extra_1.default.remove(this.dockerComposeFilePath);
                        this.logger.info('docker-compose.yml removed');
                    }
                    else {
                        this.logger.debug('No docker-compose.yml to remove');
                    }
                }
            }
            finally {
                yield fs_extra_1.default.remove(path_1.default.dirname(this.conf.path));
                this.logger.info('Host is clean');
            }
        });
    }
    get(prop) {
        return this.conf.get(prop);
    }
    set(prop, value) {
        return this.conf.set(prop, value);
    }
    get secretsDir() {
        return path_1.default.join(this.get('workingDirectory'), 'config', 'secrets');
    }
    get dockerComposeFilePath() {
        return path_1.default.join(this.get('workingDirectory'), 'docker-compose.yml');
    }
    get configDir() {
        this.logger.debug(this.conf.path);
        return path_1.default.dirname(this.conf.path);
    }
    get localConfigDir() {
        return path_1.default.join(this.get('workingDirectory'), 'config');
    }
    get snapshotsDir() {
        return path_1.default.join(this.configDir, 'snapshots');
    }
    initSnapshot() {
        const dirPath = path_1.default.join(this.snapshotsDir, Date.now().toString());
        return fs_extra_1.default.mkdirp(dirPath).then(() => dirPath);
    }
    snapshotsList() {
        return __awaiter(this, void 0, void 0, function* () {
            const files = yield fs_extra_1.default.readdir(this.snapshotsDir);
            return files.map((fileName) => ({
                name: fileName,
                time: fs_extra_1.default.statSync(path_1.default.join(this.snapshotsDir, fileName)).mtime.getTime()
            })).sort((a, b) => {
                return b.time - a.time;
            }).map((v) => v.name);
        });
    }
    validateSnapshot(snapshot) {
        return __awaiter(this, void 0, void 0, function* () {
            const fileStat = yield fs_extra_1.default.stat(path_1.default.join(this.snapshotsDir, snapshot));
            if (!fileStat.isDirectory())
                throw new Error('Invalid snapshot');
        });
    }
}
exports.DockerStore = DockerStore;
//# sourceMappingURL=DockerStore.js.map