"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.dockerCommand = void 0;
const commander_1 = require("commander");
const DockerComposeStack_1 = require("../DockerComposeStack");
const cleanup_1 = require("./cleanup");
const init_1 = require("./init");
const snapshot_1 = require("./snapshot");
const rebuildService_1 = require("./rebuildService");
const DockerClient_1 = require("../DockerClient");
const DockerStore_1 = require("../DockerStore");
function dockerCommand(logger) {
    const store = new DockerStore_1.DockerStore(logger);
    const dockerClient = new DockerClient_1.DockerClient(store, { logger });
    const stack = new DockerComposeStack_1.DockerComposeStack(store, dockerClient, { logger });
    return commander_1.createCommand('docker')
        .addCommand(init_1.initCommand(store, stack))
        .addCommand(snapshot_1.snapshotCommand(store, stack))
        .addCommand(rebuildService_1.rebuildServiceCommand(stack))
        .addCommand(cleanup_1.cleanupCommand(store, dockerClient, logger));
}
exports.dockerCommand = dockerCommand;
//# sourceMappingURL=index.js.map