"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.initCommand = void 0;
const inquirer_1 = __importDefault(require("inquirer"));
const path_1 = __importDefault(require("path"));
const util_1 = require("../../util");
const password_generator_1 = __importDefault(require("password-generator"));
const commander_1 = require("commander");
const defaultCwd = process.cwd();
function initCommand(store, stack) {
    return commander_1.createCommand('init')
        .description('Initialize a Docker stack with secrets using a boilerplate compose file.')
        .option('--cwd [cwd]', 'Set working directory', defaultCwd)
        .option('-p, --password [password]', 'Password for the database')
        .option('-u, --user [user]', 'User for the database')
        .action((cmd) => __awaiter(this, void 0, void 0, function* () {
        const { cwd, password, user } = cmd;
        if (password && user) {
            yield stack.init(path_1.default.resolve(cwd));
            yield store.createSecrets(password, user);
        }
        else {
            yield inquirer_1.default
                .prompt([{
                    name: 'directory',
                    default: defaultCwd,
                    message: 'Select a directory',
                    type: 'input'
                }, {
                    name: 'user',
                    default: 'postgres',
                    message: 'User for the database',
                    type: 'input',
                    validate: util_1.ensureValue
                }, {
                    name: 'password',
                    default: () => password_generator_1.default(16, false),
                    message: 'Password for the database user',
                    type: 'password',
                    mask: '*',
                    validate: util_1.ensureValue
                }
            ])
                .then(({ directory, password, user }) => __awaiter(this, void 0, void 0, function* () {
                yield stack.init(directory);
                return store.createSecrets(password, user);
            }));
        }
        process.exit(0);
    }));
}
exports.initCommand = initCommand;
//# sourceMappingURL=init.js.map