"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.rebuildServiceCommand = void 0;
const commander_1 = require("commander");
const inquirer_1 = __importDefault(require("inquirer"));
const util_1 = require("../util");
function rebuildServiceCommand(stack) {
    return commander_1.createCommand('rebuild-service')
        .description('Drop and rebuild data volumes for the specified service')
        .option('--services [services]', 'Service name', (names) => util_1.servicesFromNameArg(stack, names))
        .option('--no-backup', 'Rebuild without making a backup')
        .action((cmd) => __awaiter(this, void 0, void 0, function* () {
        const { backup, services } = cmd;
        if ((services === null || services === void 0 ? void 0 : services.length) > 0) {
            yield stack.rebuildService(services, backup);
        }
        else {
            yield inquirer_1.default
                .prompt([
                util_1.selectServicesFromStack(stack),
                {
                    name: 'makeBackup',
                    default: true,
                    message: 'Make a backup first?',
                    type: 'confirm'
                }
            ])
                .then((answers) => __awaiter(this, void 0, void 0, function* () {
                const { makeBackup, services } = answers;
                yield stack.rebuildService(services, makeBackup);
            }));
        }
        process.exit(0);
    }));
}
exports.rebuildServiceCommand = rebuildServiceCommand;
//# sourceMappingURL=rebuildService.js.map