"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.snapshotCommand = void 0;
const commander_1 = require("commander");
const inquirer_1 = __importDefault(require("inquirer"));
function snapshotCommand(store, stack) {
    const snapshotCmd = commander_1.createCommand('snapshot')
        .description('Make and restore snapshots of the stateful services');
    snapshotCmd
        .command('make')
        .description('Snapshot the stack')
        .action(() => __awaiter(this, void 0, void 0, function* () {
        yield stack.makeSnapshot();
        process.exit(0);
    }));
    snapshotCmd
        .command('restore')
        .description('Restore a snapshot. Omit options to be prompted')
        .option('-l, --last', 'Restore the most recent snapshot')
        .action((cmd) => __awaiter(this, void 0, void 0, function* () {
        const { last } = cmd;
        if (last === true) {
            yield stack.restoreSnapshot();
        }
        else {
            yield inquirer_1.default
                .prompt([
                {
                    name: 'snapshot',
                    message: 'Select snapshot to restore',
                    choices: () => __awaiter(this, void 0, void 0, function* () { return store.snapshotsList(); }),
                    type: 'list',
                    validate(input) {
                        if (input.length === 0) {
                            throw new Error('At least one snapshot must be selected');
                        }
                        return true;
                    }
                }
            ])
                .then(({ snapshot }) => stack.restoreSnapshot(snapshot));
        }
        process.exit(0);
    }));
    return snapshotCmd;
}
exports.snapshotCommand = snapshotCommand;
//# sourceMappingURL=snapshot.js.map